"use client";
import "@/styles/globals.css";
import type { Metadata } from "next";
import { Geist } from "next/font/google";

import {
  focusManager,
  QueryClient,
  QueryClientProvider,
} from "@tanstack/react-query";
import { useEffect } from "react";

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      refetchOnWindowFocus: true,
    },
  },
});

const geist = Geist({
  subsets: ["latin"],
  variable: "--font-geist-sans",
});

export default function RootLayout({
  children,
}: Readonly<{ children: React.ReactNode }>) {
  useEffect(() => {
    focusManager.setEventListener((handleFocus) => {
      const focus = () => {
        if (!document.hidden) {
          // console.log("Focus from parent");
          handleFocus(true);
          queryClient.refetchQueries(); // Without this, the above 'focus from parent' will be logged but queries will only refetch the first time the window is refocused from a different program. After that, data will not be refetched.
        }
      };
      window.addEventListener("visibilitychange", focus);
      window.addEventListener("focus", focus);
      return () => {
        window.removeEventListener("visibilitychange", focus);
        window.removeEventListener("focus", focus);
      };
    });
  }, []);

  return (
    <html lang="en" className={`${geist.variable}`}>
      <body>
        <QueryClientProvider client={queryClient}>
          {children}
        </QueryClientProvider>
      </body>
    </html>
  );
}
