"use client";

import { FoldableList } from "@/components/foldable-list";
import type { Result } from "@/lib/types";
import { useQuery } from "@tanstack/react-query";

const fetcher = (url: string) => {
  return fetch(url).then((r) => r.json());
};

// Update the page component to use full width
export default function Home() {
  const { isPending, error, data, isError } = useQuery({
    queryKey: ["historicData"],
    queryFn: () => fetcher(`${window.location}/api/data`),
  });

  return (
    <main className="flex min-h-screen flex-col items-center justify-center p-6 bg-zinc-800 text-white">
      <div className="w-full max-w-4xl mx-auto">
        <h1 className="text-2xl font-semibold mb-6 text-center">
          {/* Corporate Planning AG - Historic Test Data */}
          Historic Test Data
        </h1>
        <div className="">
          {isError && (
            <div>
              <h1>Encountered an Error while running the Query.</h1>
              <code>{error.message}</code>
            </div>
          )}

          {(!isPending && <FoldableList results={data as Result[]} />) || (
            <h1 className="text-2xl font-semibold mb-6 text-center">
              Loading...
            </h1>
          )}
        </div>
      </div>
    </main>
  );
}
